==========
Background
==========

Want to know more about the Rubicon project, it's history, community, and
plans for the future? That's what you'll find here!

.. toctree::
   :maxdepth: 1

   faq
   community
   success
   releases
   roadmap
